@@ -1,3 +1,4 @@
+import datetime
 import gzip
 import json
 
@@ -16,12 +17,32 @@ def __get_index_file():
     return index
 
 
-__index = __get_index_file()
-__relic_dict = __index['relics']
-__price_dict = __index['prices']
-__ducat_dict = __index['ducats']
-__required_dict = __index['required_count']
-__nv_relics = __index['non_vaulted']
+def update_index_file():
+    global __index, __relic_dict, __price_dict, __ducat_dict, __required_dict, __nv_relics, __type_dict
+    __index.update(__get_index_file())
+    __relic_dict.update(__index['relics'])
+    __price_dict.update(__index['prices'])
+    __ducat_dict.update(__index['ducats'])
+    __required_dict.update(__index['required_count'])
+    __nv_relics = __index['non_vaulted']
+    __type_dict.update(__index['types'])
+
+
+__index = {}
+__relic_dict = {}
+__price_dict = {}
+__ducat_dict = {}
+__required_dict = {}
+__nv_relics = []
+__type_dict = {}
+
+update_index_file()
+
+
+def index_last_modified():
+    last_modified = requests.head("http://198.46.233.213/index/index.json.gz").headers['Last-Modified']
+    return datetime.datetime.strptime(last_modified, '%a, %d %b %Y %H:%M:%S %Z')
+
 
 __rarity_dict = {
     'i': {
@@ -236,6 +257,18 @@ def get_non_vaulted_relics():
     return __nv_relics
 
 
+def get_type_dict():
+    return __type_dict
+
+
+def get_set_type(item):
+    item_type = None
+    if item in __type_dict:
+        item_type = __type_dict[item]
+
+    return item_type
+
+
 def get_vaulted_relics():
     return list(set(__relic_dict) - set(__nv_relics))
 
